@@ -29,7 +29,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <regex.h>
 #include <stdio_ext.h>
 
 static int debug = 0;
@@ -205,7 +204,6 @@ auparse_state_t *auparse_init(ausource_t source, const void *b)
 	au->expr = NULL;
 	au->find_field = NULL;
 	au->search_where = AUSEARCH_STOP_EVENT;
-	au->regex_valid = 0;
 
 	return au;
 bad_exit:
@@ -343,10 +341,6 @@ static int ausearch_add_item_internal(auparse_state_t *au, const char *field,
 	if (field == NULL)
 		goto err_out;
 
-	// Do not allow regex to get replaced this way
-	if (au->regex_valid != 0)
-		goto err_out;
-
 	// Make sure how is within range
 	if (how < AUSEARCH_RULE_CLEAR || how > AUSEARCH_RULE_AND)
 		goto err_out;
@@ -421,10 +415,6 @@ found_op:
 	if (milli >= 1000)
 		goto err_out;
 
-	// Do not allow regex to get replaced this way
-	if (au->regex_valid != 0)
-		goto err_out;
-
 	// Make sure how is within range
 	if (how < AUSEARCH_RULE_CLEAR || how > AUSEARCH_RULE_AND)
 		goto err_out;
@@ -447,9 +437,6 @@ int ausearch_add_expression(auparse_state_t *au, const char *expression,
 {
 	struct expr *expr;
 
-	// Do not allow regex to get replaced this way
-	if (au->regex_valid != 0)
-		goto err_einval;
 	if (how < AUSEARCH_RULE_CLEAR || how > AUSEARCH_RULE_AND)
 		goto err_einval;
 
@@ -470,25 +457,20 @@ err:
 	return -1;
 }
 
-int ausearch_add_regex(auparse_state_t *au, const char *expr)
+int ausearch_add_regex(auparse_state_t *au, const char *regexp)
 {
-	int rc;
+	struct expr *expr;
 
 	// Make sure there's an expression
+	if (regexp == NULL)
+		goto err_out;
+
+	expr = expr_create_regexp_expression(regexp);
 	if (expr == NULL)
-		goto err_out;
-
-	if (au->regex_valid != 0 || au->expr != NULL)
-		goto err_out;
-
-	// Compile expression now to make sure the expression is correct
-	rc = regcomp(&au->regex, expr, REG_EXTENDED|REG_NOSUB);
-	if (rc) {
-		goto err_out;
-	}
-	au->regex_valid = 1;
-
-	return 0; 
+		return -1;
+	if (add_expr(au, expr, AUSEARCH_RULE_AND) != 0)
+		return -1; /* expr is freed by add_expr() */
+	return 0;
 
 err_out:
 	errno = EINVAL;
@@ -508,10 +490,6 @@ int ausearch_set_stop(auparse_state_t *au, austop_t where)
 
 void ausearch_clear(auparse_state_t *au)
 {
-	if (au->regex_valid != 0) {
-		regfree(&au->regex);
-		au->regex_valid = 0;
-	}
 	if (au->expr != NULL) {
 		expr_free(au->expr);
 		au->expr = NULL;
@@ -804,10 +782,6 @@ static int retrieve_next_line(auparse_state_t *au)
 		case AUSOURCE_FILE_ARRAY:
 			// if the first time through, open file
 			if (au->list_idx == 0 && au->in == NULL) {
-				if (au->source_list[au->list_idx] == NULL) {
-					errno = 0;
-					return -2;
-				}
 				au->line_number = 0;
 				au->in = fopen(au->source_list[au->list_idx],
 									"r");
@@ -901,16 +875,6 @@ static int ausearch_compare(auparse_state_t *au)
 {
 	rnode *r;
 
-	if (au->regex_valid != 0) {
-		int rc;
-
-		r = aup_list_get_cur(&au->le);
-		rc = regexec(&au->regex, r->record, 0, NULL, 0);
-		if (rc == 0)
-			return 1;
-		else
-			return 0;
-	}
 	r = aup_list_get_cur(&au->le);
 	if (r)
 		return expr_eval(au, r, au->expr);
@@ -923,7 +887,7 @@ int ausearch_next_event(auparse_state_t *au)
 {
 	int rc;
 
-	if (au->expr == NULL && au->regex_valid == 0) {
+	if (au->expr == NULL) {
 		errno = EINVAL;
 		return -1;
 	}
