@@ -84,7 +84,7 @@ static char *escape(const char *tmp)
 	char *name;
 	const unsigned char *p = (unsigned char *)tmp;
 	while (*p) {
-		if (*p == '"' || *p < 0x21 || *p > 0x7f) {
+		if (*p == '"' || *p < 0x21 || *p > 0x7e) {
 			int len = strlen(tmp);
 			name = malloc((2*len)+1);
 			return _audit_c2x(name, tmp, len);
@@ -160,17 +160,23 @@ static int parse_up_record(rnode* r)
 			}
 			// Make virtual keys or just store it
 			if (strcmp(n.name, "key") == 0 && *n.val != '(') {
-				char *key = (char *)au_unescape(n.val);
-				char *ptr = strtok_r(key, key_sep, &saved);
-				free(n.name);
-				free(n.val);
-				while (ptr) {
-					n.name = strdup("key");
-					n.val = escape(ptr);
+				if (*n.val == '"')
 					nvlist_append(&r->nv, &n);
-					ptr = strtok_r(NULL, key_sep, &saved);
+				else {
+					char *key = (char *)au_unescape(n.val);
+					char *ptr = strtok_r(key,
+							key_sep, &saved);
+					free(n.name);
+					free(n.val);
+					while (ptr) {
+						n.name = strdup("key");
+						n.val = escape(ptr);
+						nvlist_append(&r->nv, &n);
+						ptr = strtok_r(NULL,
+							key_sep, &saved);
+					}
+					free(key);
 				}
-				free(key);
 				continue;
 			} else
 				nvlist_append(&r->nv, &n);
@@ -212,6 +218,7 @@ static int parse_up_record(rnode* r)
 		} else if (r->type == AUDIT_AVC || r->type == AUDIT_USER_AVC) {
 			// We special case these 2 fields because selinux
 			// avc messages do not label these fields.
+			n.name = NULL;
 			if (nvlist_get_cnt(&r->nv) == (1 + offset)) {
 				// skip over 'avc:'
 				if (strncmp(ptr, "avc", 3) == 0)
@@ -282,7 +289,7 @@ int aup_list_append(event_list_t *l, char *record, int list_idx,
 	nvlist_create(&r->nv);
 
 	// if we are at top, fix this up
-	if (l->head == 0)
+	if (l->head == NULL)
 		l->head = r;
 	else {	// Otherwise add pointer to newnode
 		aup_list_last(l);
