@@ -22,6 +22,7 @@
 */
 
 #include <assert.h>
+#include <errno.h>
 #include <limits.h>
 #include <stdlib.h>
 #include <string.h>
@@ -58,6 +59,11 @@ expr_free(struct expr *expr)
 		free(expr->v.p.field.name);
 		break;
 
+	case EO_REGEXP_MATCHES:
+		regfree(expr->v.regexp);
+		free(expr->v.regexp);
+		break;
+
 	default:
 		abort();
 	}
@@ -81,15 +87,18 @@ expr_free(struct expr *expr)
    primary-expression: comparison-expression
 
    comparison-expression: field op value
+   comparison-expression: field-escape "regexp" regexp-value
    field: string
    field: field-escape string
-   value: string */
+   value: string
+   regexp-value: string
+   regexp-value: regexp */
 
 /* Token types */
 enum token_type {
 	/* EO_* */
-	T_LEFT_PAREN = NUM_EO_VALUES, T_RIGHT_PAREN, T_STRING, T_FIELD_ESCAPE,
-	T_UNKNOWN, T_EOF
+	T_LEFT_PAREN = NUM_EO_VALUES, T_RIGHT_PAREN, T_STRING, T_REGEXP,
+	T_FIELD_ESCAPE, T_UNKNOWN, T_EOF
 };
 
 /* Expression parsing status */
@@ -161,25 +170,27 @@ lex(struct parsing *p)
 		p->token = EO_NOT;
 		break;
 
-	case '"': {
-		char *buf;
+	case '"': case '/': {
+		char *buf, delimiter;
 		size_t dest, buf_size;
 
+		delimiter = *p->src;
 		buf_size = 8;
 		buf = parser_malloc(p, buf_size);
 		if (buf == NULL)
 			return -1;
 		p->src++;
 		dest = 0;
-		while (*p->src != '"') {
+		while (*p->src != delimiter) {
 			if (*p->src == '\0') {
-				*p->error = strdup("Terminating quote missing");
+				*p->error = strdup("Terminating delimiter "
+						   "missing");
 				free(buf);
 				return -1;
 			}
 			if (*p->src == '\\') {
 				p->src++;
-				if (*p->src != '\\' && *p->src != '"') {
+				if (*p->src != '\\' && *p->src != delimiter) {
 					*p->error = NULL;
 					asprintf(p->error, "Unknown escape "
 						 "sequence ``\\%c''", *p->src);
@@ -191,8 +202,8 @@ lex(struct parsing *p)
 			   NUL. */
 			if (dest + 1 >= buf_size) {
 				if (buf_size > SIZE_MAX / 2) {
-					*p->error = strdup("Quoted string too "
-							   "long");
+					*p->error = strdup("Delimited string "
+							   "too long");
 					free(buf);
 					return -1;
 				}
@@ -212,7 +223,7 @@ lex(struct parsing *p)
 		p->token_value = parser_realloc(p, buf, dest + 1);
 		if (p->token_value == NULL)
 			return -1;
-		p->token = T_STRING;
+		p->token = delimiter == '/' ? T_REGEXP : T_STRING;
 		break;
 	}
 
@@ -428,6 +439,56 @@ parse_virtual_field_value(struct expr *dest, struct parsing *p)
 	}
 }
 
+/* Parse a \regexp comparison-expression string in *P, with \regexp parsed.
+   Use or free EXPR.
+   On success, return the parsed comparison-expression.
+   On error, set *P->ERROR to an error string (for free()) or NULL, and return
+   NULL. */
+static struct expr *
+parse_comparison_regexp(struct parsing *p, struct expr *res)
+{
+	int err;
+
+	if (lex(p) != 0)
+		goto err_res;
+	if (p->token != T_STRING && p->token != T_REGEXP) {
+		*p->error = NULL;
+		asprintf(p->error, "Regexp expected, got `%.*s'", p->token_len,
+			 p->token_start);
+		goto err_res;
+	}
+	res->v.regexp = parser_malloc(p, sizeof(*res->v.regexp));
+	if (res->v.regexp == NULL)
+		goto err_res;
+	err = regcomp(res->v.regexp, p->token_value, REG_EXTENDED | REG_NOSUB);
+	if (err != 0) {
+		size_t err_size;
+		char *err_msg;
+
+		err_size = regerror(err, res->v.regexp, NULL, 0);
+		err_msg = parser_malloc(p, err_size);
+		if (err_msg == NULL)
+			goto err_res_regexp;
+		regerror(err, res->v.regexp, err_msg, err_size);
+		*p->error = NULL;
+		asprintf(p->error, "Invalid regexp: %s", err_msg);
+		free(err_msg);
+		goto err_res_regexp;
+	}
+	res->op = EO_REGEXP_MATCHES;
+	if (lex(p) != 0) {
+		expr_free(res);
+		return NULL;
+	}
+	return res;
+
+err_res_regexp:
+	free(res->v.regexp);
+err_res:
+	free(res);
+	return NULL;
+}
+
 /* Parse a comparison-expression string in *P.
    On success, return the parsed comparison-expression.
    On error, set *P->ERROR to an error string (for free()) or NULL, and return
@@ -448,6 +509,8 @@ parse_comparison(struct parsing *p)
 					   "escape");
 			goto err_res;
 		}
+		if (strcmp(p->token_value, "regexp") == 0)
+			return parse_comparison_regexp(p, res);
 		res->virtual_field = 1;
 		if (parse_escaped_field_name(&res->v.p.field.id, p->token_value)
 		    != 0) {
@@ -777,6 +840,35 @@ err:
 	return NULL;
 }
 
+/* Create a \regexp expression for regexp comparison.
+   On success, return the created expression.
+   On error, set errno and return NULL. */
+struct expr *
+expr_create_regexp_expression(const char *regexp)
+{
+	struct expr *res;
+
+	res = malloc(sizeof(*res));
+	if (res == NULL)
+		goto err;
+	res->v.regexp = malloc(sizeof(*res->v.regexp));
+	if (res->v.regexp == NULL)
+		goto err_res;
+	if (regcomp(res->v.regexp, regexp, REG_EXTENDED | REG_NOSUB) != 0) {
+		errno = EINVAL;
+		goto err_res_regexp;
+	}
+	res->op = EO_REGEXP_MATCHES;
+	return res;
+
+err_res_regexp:
+	free(res->v.regexp);
+err_res:
+	free(res);
+err:
+	return NULL;
+}
+
 /* Create a binary expresion for OP and subexpressions E1 and E2.
    On success, return the created expresion.
    On error, set errno and return NULL. */
@@ -972,6 +1064,9 @@ expr_eval(auparse_state_t *au, rnode *record, const struct expr *expr)
 		nvlist_first(&record->nv);
 		return nvlist_find_name(&record->nv, expr->v.p.field.name) != 0;
 
+	case EO_REGEXP_MATCHES:
+		return regexec(expr->v.regexp, record->record, 0, NULL, 0) == 0;
+
 	default:
 		abort();
 	}
