@@ -1,6 +1,6 @@
 
 /* typetab.h --
- * Copyright 2007-08 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2007-09 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -41,32 +41,38 @@ _S(AUPARSE_TYPE_GID,		"ogid"		)
 _S(AUPARSE_TYPE_GID,		"igid"		)
 _S(AUPARSE_TYPE_GID,		"inode_gid"	)
 _S(AUPARSE_TYPE_GID,		"new_gid"	)
-_S(AUPARSE_TYPE_SYSCALL,		"syscall"	)
+_S(AUPARSE_TYPE_SYSCALL,	"syscall"	)
 _S(AUPARSE_TYPE_ARCH,		"arch"		)
 _S(AUPARSE_TYPE_EXIT,		"exit"		)
-_S(AUPARSE_TYPE_ESCAPED,		"path"		)
-_S(AUPARSE_TYPE_ESCAPED,		"comm"		)
-_S(AUPARSE_TYPE_ESCAPED,		"exe"		)
-_S(AUPARSE_TYPE_ESCAPED,		"file"		)
-_S(AUPARSE_TYPE_ESCAPED,		"name"		)
-_S(AUPARSE_TYPE_ESCAPED,		"watch"		)
-_S(AUPARSE_TYPE_ESCAPED,		"cwd"		)
-_S(AUPARSE_TYPE_ESCAPED,		"cmd"		)
-_S(AUPARSE_TYPE_ESCAPED,		"acct"		)
-_S(AUPARSE_TYPE_ESCAPED,		"dir"		)
-_S(AUPARSE_TYPE_ESCAPED,		"key"		)
+_S(AUPARSE_TYPE_ESCAPED,	"path"		)
+_S(AUPARSE_TYPE_ESCAPED,	"comm"		)
+_S(AUPARSE_TYPE_ESCAPED,	"exe"		)
+_S(AUPARSE_TYPE_ESCAPED,	"file"		)
+_S(AUPARSE_TYPE_ESCAPED,	"name"		)
+_S(AUPARSE_TYPE_ESCAPED,	"watch"		)
+_S(AUPARSE_TYPE_ESCAPED,	"cwd"		)
+_S(AUPARSE_TYPE_ESCAPED,	"cmd"		)
+_S(AUPARSE_TYPE_ESCAPED,	"acct"		)
+_S(AUPARSE_TYPE_ESCAPED,	"dir"		)
+_S(AUPARSE_TYPE_ESCAPED,	"key"		)
 _S(AUPARSE_TYPE_PERM,		"perm"		)
 _S(AUPARSE_TYPE_PERM,		"perm_mask"	)
 _S(AUPARSE_TYPE_MODE,		"mode"		)
-_S(AUPARSE_TYPE_SOCKADDR,		"saddr"		)
+_S(AUPARSE_TYPE_SOCKADDR,	"saddr"		)
 _S(AUPARSE_TYPE_FLAGS,		"flags"		)
-_S(AUPARSE_TYPE_PROMISC,		"prom"		)
-_S(AUPARSE_TYPE_PROMISC,		"old_prom"	)
+_S(AUPARSE_TYPE_PROMISC,	"prom"		)
+_S(AUPARSE_TYPE_PROMISC,	"old_prom"	)
 _S(AUPARSE_TYPE_CAPABILITY,	"capability"	)
-_S(AUPARSE_TYPE_SUCCESS,		"res"		)
-_S(AUPARSE_TYPE_SUCCESS,		"result"	)
+_S(AUPARSE_TYPE_SUCCESS,	"res"		)
+_S(AUPARSE_TYPE_SUCCESS,	"result"	)
 _S(AUPARSE_TYPE_A0,		"a0"		)
 _S(AUPARSE_TYPE_A1,		"a1"		)
 _S(AUPARSE_TYPE_A2,		"a2"		)
 _S(AUPARSE_TYPE_SIGNAL,		"sig"		)
 _S(AUPARSE_TYPE_TTY_DATA,	"data"		)
+_S(AUPARSE_TYPE_SESSION,	"ses"		)
+_S(AUPARSE_TYPE_CAP_BITMAP,	"cap_pi"	)
+_S(AUPARSE_TYPE_CAP_BITMAP,	"cap_pe"	)
+_S(AUPARSE_TYPE_CAP_BITMAP,	"cap_pp"	)
+_S(AUPARSE_TYPE_CAP_BITMAP,	"cap_fi"	)
+_S(AUPARSE_TYPE_CAP_BITMAP,	"cap_fp"	)
