@@ -1,5 +1,5 @@
 /* libaudit.c -- 
- * Copyright 2004-2007 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2004-2009 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -92,8 +92,7 @@ static const struct kw_pair keywords[] =
   { NULL,		NULL }
 };
 
-/* FIXME: Make this static again after deprecated functions no longer need it */
-int hidden audit_priority(int xerrno)
+static int audit_priority(int xerrno)
 {
 	/* If they've compiled their own kernel and did not include
 	 * the audit susbsystem, they will get ECONNREFUSED. We'll
@@ -593,6 +592,10 @@ int audit_add_rule_data(int fd, struct audit_rule_data *rule,
 {
 	int rc;
 
+	if (flags == AUDIT_FILTER_ENTRY) {
+		audit_msg(LOG_WARNING, "Use of entry filter is deprecated");
+		return -2;
+	}
 	rule->flags  = flags;
 	rule->action = action;
 	rc = audit_send(fd, AUDIT_ADD_RULE, rule, 
@@ -610,6 +613,10 @@ int audit_delete_rule_data(int fd, struct audit_rule_data *rule,
 {
 	int rc;
 
+	if (flags == AUDIT_FILTER_ENTRY) {
+		audit_msg(LOG_WARNING, "Use of entry filter is deprecated");
+		return -2;
+	}
 	rule->flags  = flags;
 	rule->action = action;
 	rc = audit_send(fd, AUDIT_DEL_RULE, rule, 
