@@ -1,5 +1,5 @@
 /* msg_typetab.h --
- * Copyright 2005-07 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2005-07,2009 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -28,7 +28,7 @@
  */
 //_S(AUDIT_GET,                      "GET"                           )
 //_S(AUDIT_SET,                      "SET"                           )
-_S(AUDIT_LIST,                       "LIST"                          )
+//_S(AUDIT_LIST,                     "LIST"                          )
 //_S(AUDIT_ADD,                      "ADD"                           )
 //_S(AUDIT_DEL,                      "DEL"                           )
 _S(AUDIT_USER,                       "USER"                          )
@@ -188,8 +188,4 @@ _S(AUDIT_CRYPTO_LOGOUT,              "CRYPTO_LOGOUT"                 )
 _S(AUDIT_CRYPTO_KEY_USER,            "CRYPTO_KEY_USER"               )
 _S(AUDIT_CRYPTO_FAILURE_USER,        "CRYPTO_FAILURE_USER"           )
 _S(AUDIT_CRYPTO_REPLAY_USER,         "CRYPTO_REPLAY_USER"            )
-_S(AUDIT_CRYPTO_SESSION,             "CRYPTO_SESSION"                )
-_S(AUDIT_VIRT_CONTROL,               "VIRT_CONTROL"                  )
-_S(AUDIT_VIRT_RESOURCE,              "VIRT_RESOURCE"                 )
-_S(AUDIT_VIRT_MACHINE_ID,            "VIRT_MACHINE_ID"               )
 
