@@ -142,7 +142,7 @@ static int adjust_reply(struct audit_reply *rep, int len)
 	rep->len      = rep->msg.nlh.nlmsg_len;
 	rep->nlh      = &rep->msg.nlh;
 	rep->status   = NULL;
-	rep->rule     = NULL;
+	rep->ruledata = NULL;
 	rep->login    = NULL;
 	rep->message  = NULL;
 	rep->error    = NULL;
@@ -170,9 +170,6 @@ static int adjust_reply(struct audit_reply *rep, int len)
 		case AUDIT_GET:   
 			rep->status  = NLMSG_DATA(rep->nlh); 
 			break;
-		case AUDIT_LIST:  
-			rep->rule    = NLMSG_DATA(rep->nlh); 
-			break;
 		case AUDIT_LIST_RULES:  
 			rep->ruledata = NLMSG_DATA(rep->nlh); 
 			break;
@@ -181,8 +178,8 @@ static int adjust_reply(struct audit_reply *rep, int len)
 		case AUDIT_KERNEL:
 		case AUDIT_FIRST_USER_MSG...AUDIT_LAST_USER_MSG:
 		case AUDIT_FIRST_USER_MSG2...AUDIT_LAST_USER_MSG2:
-		case AUDIT_FIRST_EVENT...AUDIT_LAST_KERN_ANOM_MSG:
-			rep->message = NLMSG_DATA(rep->nlh); 
+		case AUDIT_FIRST_EVENT...AUDIT_INTEGRITY_LAST_MSG:
+			rep->message = NLMSG_DATA(rep->nlh);
 			break;
 		case AUDIT_SIGNAL_INFO:
 			rep->signal_info = NLMSG_DATA(rep->nlh);
