@@ -64,9 +64,6 @@ static int add = AUDIT_FILTER_UNSET, del = AUDIT_FILTER_UNSET, action = -1;
 static int ignore = 0;
 static int exclude = 0;
 static int multiple = 0;
-enum { OLD, NEW };
-int which;
-static struct audit_rule  rule;
 static struct audit_rule_data *rule_new = NULL;
 static char key[AUDIT_MAX_KEY_LEN+1];
 static int keylen;
@@ -94,12 +91,11 @@ static int reset_vars(void)
 	del = AUDIT_FILTER_UNSET;
 	action = -1;
 	exclude = 0;
-	which = OLD;
 	multiple = 0;
 
-	memset(&rule, 0, sizeof(rule));
 	free(rule_new);
-	rule_new = NULL;
+	rule_new = malloc(sizeof(struct audit_rule_data));
+	memset(rule_new, 0, sizeof(struct audit_rule_data));
 	if (fd < 0) {
 		if ((fd = audit_open()) < 0) {
 			fprintf(stderr, "Cannot open netlink audit socket\n");
@@ -109,29 +105,6 @@ static int reset_vars(void)
 	return 0;
 }
 
-static void upgrade_rule(void)
-{
-	int i;
-
-	rule_new=malloc(sizeof(struct audit_rule_data));
-	memset(rule_new, 0, sizeof(struct audit_rule_data));
-	memcpy(rule_new, &rule, sizeof(rule));
-	which = NEW;
-	if (rule_new->field_count == 0)
-		return;
-
-	// now go through fields and move legacy ops to fieldflags
-	for (i=0; i<rule_new->field_count; i++) {
-		uint32_t ops = rule_new->fields[i] & 
-				(AUDIT_NEGATE|AUDIT_OPERATORS);
-		rule_new->fields[i] &= ~(AUDIT_NEGATE|AUDIT_OPERATORS);
-		if (ops & AUDIT_NEGATE)
-			rule_new->fieldflags[i] = AUDIT_NOT_EQUAL;
-		else
-			rule_new->fieldflags[i] = AUDIT_EQUAL; 
-	}
-}
-
 static void usage(void)
 {
     printf(
@@ -203,7 +176,7 @@ static int lookup_action(const char *str, int *act)
  * Returns 0 ok, 1 deprecated action, 2 rule error,
  * 3 multiple rule insert/delete
  */
-static int audit_rule_setup(char *opt, int *filter, int *act)
+static int audit_rule_setup(char *opt, int *filter, int *act, int lineno)
 {
 	int rc;
 	char *p;
@@ -242,6 +215,16 @@ static int audit_rule_setup(char *opt, int *filter, int *act)
 	if (*filter == AUDIT_FILTER_UNSET || *act == -1)
 		return 2;
 
+	/* Consolidate rules on exit filter */
+	if (*filter == AUDIT_FILTER_ENTRY) {
+		*filter = AUDIT_FILTER_EXIT;
+		fprintf(stderr,
+		    "Warning - entry rules deprecated, changing to exit rule");
+		if (lineno)
+			fprintf(stderr, " in line %d", lineno);
+		fprintf(stderr, "\n");
+	}
+
 	return 0;
 }
 
@@ -350,7 +333,7 @@ static int audit_setup_perms(struct audit_rule_data *rule, const char *opt)
 		}
 	}
 
-	if (audit_update_watch_perms(rule, val) == 0) {
+	if (audit_update_watch_perms(rule_new, val) == 0) {
 		audit_permadded = 1;
 		return 1;
 	}
@@ -443,23 +426,15 @@ static int equiv_parse(char *optarg, char **mp, char **sub)
 
 void audit_request_rule_list(int fd)
 {
-	int rc;
-
-	/* Try out the new message type */
-	if ((rc = audit_request_rules_list_data(fd)) > 0) {
+	if (audit_request_rules_list_data(fd) > 0) {
 		list_requested = 1;
 		get_reply();
-	} else if (rc == -EINVAL) { /* Not supported...drop back to old one */
-		if (audit_request_rules_list(fd) > 0) {
-			list_requested = 1;
-			get_reply();
-		}
 	}
 }
 
 void check_rule_mismatch(int lineno, const char *option)
 {
-	struct audit_rule tmprule;
+	struct audit_rule_data tmprule;
 	unsigned int old_audit_elf = audit_elf;
 	int rc = 0;
 
@@ -475,15 +450,10 @@ void check_rule_mismatch(int lineno, const char *option)
 			audit_elf = AUDIT_ARCH_S390;
 			break;
 	}
-	memset(&tmprule, 0, sizeof(struct audit_rule));
-	audit_rule_syscallbyname(&tmprule, option);
-	if (which == OLD) {
-		if (memcmp(tmprule.mask, rule.mask, AUDIT_BITMASK_SIZE))
-			rc = 1;
-	} else {
-		if (memcmp(tmprule.mask, rule_new->mask, AUDIT_BITMASK_SIZE))
-			rc = 1;
-	}
+	memset(&tmprule, 0, sizeof(struct audit_rule_data));
+	audit_rule_syscallbyname_data(&tmprule, option);
+	if (memcmp(tmprule.mask, rule_new->mask, AUDIT_BITMASK_SIZE))
+		rc = 1;
 	audit_elf = old_audit_elf;
 	if (rc) { 
 		fprintf(stderr, "WARNING - 32/64 bit syscall mismatch");
@@ -519,7 +489,6 @@ static int setopt(int count, int lineno, char *vars[])
 		break;
 	case 'i':
 		ignore = 1;
-		retval = -2;
 		break;
         case 's':
 		retval = audit_request_status(fd);
@@ -622,7 +591,7 @@ static int setopt(int count, int lineno, char *vars[])
 				"Syscall auditing requested for task list\n");
 			retval = -1;
 		} else {
-			rc = audit_rule_setup(optarg, &add, &action);
+			rc = audit_rule_setup(optarg, &add, &action, lineno);
 			if (rc == 3) {
 				fprintf(stderr,
 		"Multiple rule insert/delete operations are not allowed\n");
@@ -646,7 +615,7 @@ static int setopt(int count, int lineno, char *vars[])
 			   "Error: syscall auditing requested for task list\n");
 			retval = -1;
 		} else {
-			rc = audit_rule_setup(optarg, &add, &action);
+			rc = audit_rule_setup(optarg, &add, &action, lineno);
 			if (rc == 3) {
 				fprintf(stderr,
 		"Multiple rule insert/delete operations are not allowed\n");
@@ -666,7 +635,7 @@ static int setopt(int count, int lineno, char *vars[])
 		}
 		break;
         case 'd': 
-		rc = audit_rule_setup(optarg, &del, &action);
+		rc = audit_rule_setup(optarg, &del, &action, lineno);
 		if (rc == 3) {
 			fprintf(stderr,
 		"Multiple rule insert/delete operations are not allowed\n");
@@ -723,11 +692,7 @@ static int setopt(int count, int lineno, char *vars[])
 				audit_elf = elf;
 			}
 		}
-		if (which == OLD) 
-			rc = audit_rule_syscallbyname(&rule, optarg);
-		else
-			rc = audit_rule_syscallbyname(
-				(struct audit_rule *)rule_new, optarg);
+		rc = audit_rule_syscallbyname_data(rule_new, optarg);
 		switch (rc)
 		{
 			case 0:
@@ -760,21 +725,13 @@ static int setopt(int count, int lineno, char *vars[])
 			retval = -1;
 			break;
 		}
-		if (which == OLD) {
-			char *ptr = strdup(optarg);
-			rc = audit_rule_fieldpair(&rule, ptr, flags);
-			if (rc == -10)
-				upgrade_rule(); /* need to upgrade... */
-			free(ptr);
-		}
-		if (which == NEW) 
-			rc = audit_rule_fieldpair_data(&rule_new,optarg,flags);
 
+		rc = audit_rule_fieldpair_data(&rule_new,optarg,flags);
 		if (rc != 0) {
 			audit_number_to_errmsg(rc, optarg);
 			retval = -1;
 		} else {
-			if (which == NEW && rule_new->fields[rule_new->field_count-1] ==
+			if (rule_new->fields[rule_new->field_count-1] ==
 						AUDIT_PERM)
 				audit_permadded = 1;
 		}
@@ -829,7 +786,6 @@ static int setopt(int count, int lineno, char *vars[])
 		} else if (optarg) { 
 			add = AUDIT_FILTER_EXIT;
 			action = AUDIT_ALWAYS;
-			which = NEW;
 			audit_syscalladded = 1;
 			retval = audit_setup_watch_name(&rule_new, optarg);
 		} else {
@@ -841,7 +797,6 @@ static int setopt(int count, int lineno, char *vars[])
 		if (optarg) { 
 			del = AUDIT_FILTER_EXIT;
 			action = AUDIT_ALWAYS;
-			which = NEW;
 			audit_syscalladded = 1;
 			retval = audit_setup_watch_name(&rule_new, optarg);
 		} else {
@@ -889,14 +844,8 @@ static int setopt(int count, int lineno, char *vars[])
 		} else if (!optarg) {
 			fprintf(stderr, "permission option needs a filter\n");
 			retval = -1;
-		} else {
-			if (which == OLD) {
-				fprintf(stderr,
-				"You must give a watch prior to perms\n");
-				retval = -1;
-			} else 
-				retval = audit_setup_perms(rule_new, optarg);
-		}
+		} else 
+			retval = audit_setup_perms(rule_new, optarg);
 		break;
         case 'q':
 		if (audit_syscalladded) {
@@ -959,10 +908,7 @@ static int setopt(int count, int lineno, char *vars[])
 	asprintf(&cmd, "key=%s", key);
 	if (cmd) {
 		/* Add this to the rule */
-		int ret;
-		if (which == OLD)
-			upgrade_rule();
-		ret = audit_rule_fieldpair_data(&rule_new, cmd, flags);
+		int ret = audit_rule_fieldpair_data(&rule_new, cmd, flags);
 		if (ret < 0)
 			retval = -1;
 		free(cmd);
@@ -1094,7 +1040,7 @@ static int fileopt(const char *file)
 					fclose(f);
 					return 0;
 				}
-				if (ignore == 0) {
+				if (!ignore) {
 					fclose(f);
 					return -1;
 				}
@@ -1139,11 +1085,15 @@ int main(int argc, char *argv[])
 		else
 			return 0;
 	} else {
-		if (reset_vars())
+		if (reset_vars()) {
+			free(rule_new);
 			return 1;
+		}
 		retval = setopt(argc, 0, argv);
-		if (retval == -3)
+		if (retval == -3) {
+			free(rule_new);
 			return 0;
+		}
 	}
 
 	if (add != AUDIT_FILTER_UNSET || del != AUDIT_FILTER_UNSET) {
@@ -1152,9 +1102,11 @@ int main(int argc, char *argv[])
 			fprintf(stderr,
 				"The audit system is in immutable "
 				"mode, no rules loaded\n");
+			free(rule_new);
 			return 0;
 		} else if (errno == ECONNREFUSED) {
 			fprintf(stderr, "The audit system is disabled\n");
+			free(rule_new);
 			return 0;
 		}
 	}
@@ -1185,68 +1137,49 @@ static int handle_request(int status)
 			// if !task add syscall any if not specified
 			if ((add & AUDIT_FILTER_MASK) != AUDIT_FILTER_TASK && 
 					audit_syscalladded != 1) {
-				if (which == OLD)
-					audit_rule_syscallbyname(&rule, "all");
-				else
 					audit_rule_syscallbyname_data(
 							rule_new, "all");
 			}
-			if (which == OLD) {
-				rc = audit_add_rule(fd, &rule, add, action);
-			} else {
-				set_aumessage_mode(MSG_QUIET, DBG_NO);
-				rc = audit_add_rule_data(fd, rule_new,
-								 add, action);
-				set_aumessage_mode(MSG_STDERR, DBG_NO);
-				/* Retry for legacy kernels */
-				if (rc < 0) {
-					if (errno == EINVAL &&
-					rule_new->fields[0] == AUDIT_DIR) {
-						rule_new->fields[0] =
-								AUDIT_WATCH;
-						rc = audit_add_rule_data(fd,
-								rule_new,
-								add, action);
-					} else {
-						fprintf(stderr,
+			set_aumessage_mode(MSG_QUIET, DBG_NO);
+			rc = audit_add_rule_data(fd, rule_new, add, action);
+			set_aumessage_mode(MSG_STDERR, DBG_NO);
+			/* Retry for legacy kernels */
+			if (rc < 0) {
+				if (errno == EINVAL &&
+				rule_new->fields[0] == AUDIT_DIR) {
+					rule_new->fields[0] = AUDIT_WATCH;
+					rc = audit_add_rule_data(fd, rule_new,
+							add, action);
+				} else {
+					fprintf(stderr,
 				"Error sending add rule data request (%s)\n",
-						errno == EEXIST ?
-						"Rule exists" : strerror(-rc));
-					}
+					errno == EEXIST ?
+					"Rule exists" : strerror(-rc));
 				}
 			}
 		}
 		else if (del != AUDIT_FILTER_UNSET) {
 			if ((del & AUDIT_FILTER_MASK) != AUDIT_FILTER_TASK && 
 					audit_syscalladded != 1) {
-				if (which == OLD)
-					audit_rule_syscallbyname(&rule, "all");
-				else
 					audit_rule_syscallbyname_data(
 							rule_new, "all");
 			}
-			if (which == OLD)
-				rc = audit_delete_rule(fd, &rule, del, action);
-			else {
-				set_aumessage_mode(MSG_QUIET, DBG_NO);
-				rc = audit_delete_rule_data(fd, rule_new,
+			set_aumessage_mode(MSG_QUIET, DBG_NO);
+			rc = audit_delete_rule_data(fd, rule_new,
 								 del, action);
-				set_aumessage_mode(MSG_STDERR, DBG_NO);
-				/* Retry for legacy kernels */
-				if (rc < 0) {
-					if (errno == EINVAL &&
+			set_aumessage_mode(MSG_STDERR, DBG_NO);
+			/* Retry for legacy kernels */
+			if (rc < 0) {
+				if (errno == EINVAL &&
 					rule_new->fields[0] == AUDIT_DIR) {
-						rule_new->fields[0] =
-								AUDIT_WATCH;
-						rc = audit_delete_rule_data(fd,
-								rule_new,
+					rule_new->fields[0] = AUDIT_WATCH;
+					rc = audit_delete_rule_data(fd,rule_new,
 								del, action);
-					} else {
-						fprintf(stderr,
+				} else {
+					fprintf(stderr,
 			       "Error sending delete rule data request (%s)\n",
-						errno == EEXIST ?
-						"Rule exists" : strerror(-rc));
-					}
+					errno == EEXIST ?
+					"Rule exists" : strerror(-rc));
 				}
 			}
 		} else {
@@ -1317,13 +1250,8 @@ int key_match(struct audit_reply *rep)
 		return 1;
 
 	// At this point, we have a key
-	// Old records don't have keys
-	if (rep->type == AUDIT_LIST)
-		return 0;
-
-	for (i = 0; i < rep->rule->field_count; i++) {
-		int field = rep->rule->fields[i] &
-					~AUDIT_OPERATORS & ~AUDIT_NEGATE;
+	for (i = 0; i < rep->ruledata->field_count; i++) {
+		int field = rep->ruledata->fields[i] & ~AUDIT_OPERATORS;
 		if (field == AUDIT_FILTERKEY) {
 			char *keyptr;
 			asprintf(&keyptr, "%.*s", rep->ruledata->values[i],
@@ -1380,7 +1308,6 @@ static int audit_print_reply(struct audit_reply *rep)
 			rep->status->backlog);
 			printed = 1;
 			return 0;
-		case AUDIT_LIST:
 		case AUDIT_LIST_RULES:
 			list_requested = 0;
 			boffset = 0;
@@ -1389,39 +1316,35 @@ static int audit_print_reply(struct audit_reply *rep)
 				return 1;
 			printed = 1;
 			printf("%s: %s,%s", audit_msg_type_to_name(rep->type),
-				audit_flag_to_name((int)rep->rule->flags),
-				audit_action_to_name(rep->rule->action));
+				audit_flag_to_name((int)rep->ruledata->flags),
+				audit_action_to_name(rep->ruledata->action));
 
-			for (i = 0; i < rep->rule->field_count; i++) {
+			for (i = 0; i < rep->ruledata->field_count; i++) {
 				const char *name;
-				int op;
-				int field = rep->rule->fields[i] &
-					~AUDIT_OPERATORS & ~AUDIT_NEGATE;
-				if (rep->type == AUDIT_LIST_RULES) {
-					op = rep->ruledata->fieldflags[i] &
-					(AUDIT_OPERATORS | AUDIT_NEGATE);
-				} else {
-					op = rep->rule->fields[i] &
-					    (AUDIT_OPERATORS | AUDIT_NEGATE);
-				}
+				int op = rep->ruledata->fieldflags[i] &
+						AUDIT_OPERATORS;
+				int field = rep->ruledata->fields[i] &
+						~AUDIT_OPERATORS;
                 
 				name = audit_field_to_name(field);
 				if (name) {
 					if (strcmp(name, "arch") == 0) { 
-						audit_elf =rep->rule->values[i];
+						audit_elf =
+						    rep->ruledata->values[i];
 						printf(" %s%s%u", name, 
-							audit_operator_to_symbol(op),
-							(unsigned)rep->rule->values[i]);
+						  audit_operator_to_symbol(op),
+					    (unsigned)rep->ruledata->values[i]);
 					}
 					else if (strcmp(name, "msgtype") == 0) {
-						if (!audit_msg_type_to_name(rep->rule->values[i]))
+						if (!audit_msg_type_to_name(
+						      rep->ruledata->values[i]))
 							printf(" %s%s%d", name,
 								audit_operator_to_symbol(op),
-								rep->rule->values[i]);
+								rep->ruledata->values[i]);
 						else {
 							printf(" %s%s%s", name,
 								audit_operator_to_symbol(op),
-								audit_msg_type_to_name(rep->rule->values[i]));
+								audit_msg_type_to_name(rep->ruledata->values[i]));
 						}
 					} else if ((field >= AUDIT_SUBJ_USER &&
 						  field <= AUDIT_OBJ_LEV_HIGH)
@@ -1461,7 +1384,7 @@ static int audit_print_reply(struct audit_reply *rep)
 						free(rkey);
 					} else if (field == AUDIT_PERM) {
 						char perms[5];
-						int val=rep->rule->values[i];
+						int val=rep->ruledata->values[i];
 						perms[0] = 0;
 						if (val & AUDIT_PERM_READ)
 							strcat(perms, "r");
@@ -1473,43 +1396,37 @@ static int audit_print_reply(struct audit_reply *rep)
 							strcat(perms, "a");
 						printf(" perm=%s", perms);
 						show_syscall = 0;
-					} else if (field == AUDIT_INODE) {
-						// Unsigned items
-						printf(" %s%s%u", name, 
-							audit_operator_to_symbol(op),
-							rep->ruledata->values[i]);
 					} else {
-						// Signed items
 						printf(" %s%s%d", name, 
 							audit_operator_to_symbol(op),
-							rep->rule->values[i]);
+							rep->ruledata->values[i]);
 					}
 				} else { 
-					printf(" f%d%s%d", rep->rule->fields[i],
+					printf(" f%d%s%d", rep->ruledata->fields[i],
 						audit_operator_to_symbol(op),
-						rep->rule->values[i]);
+						rep->ruledata->values[i]);
 				}
 				/* Avoid printing value if the field type is 
 				 * known to return a string. */
-				if (rep->rule->values[i] && 
+				if (rep->ruledata->values[i] && 
 						(field < AUDIT_SUBJ_USER ||
 						 field > AUDIT_SUBJ_CLR) &&
 						field != AUDIT_WATCH &&
 						field != AUDIT_FILTERKEY &&
 						field != AUDIT_PERM)
-					printf(" (0x%x)", rep->rule->values[i]);
+					printf(" (0x%x)", rep->ruledata->values[i]);
 			}
 			if (show_syscall &&
-				((rep->rule->flags & AUDIT_FILTER_MASK) != 
+				((rep->ruledata->flags & AUDIT_FILTER_MASK) != 
 						AUDIT_FILTER_USER) &&
-				((rep->rule->flags & AUDIT_FILTER_MASK) !=
+				((rep->ruledata->flags & AUDIT_FILTER_MASK) !=
 						AUDIT_FILTER_TASK) &&
-				((rep->rule->flags & AUDIT_FILTER_MASK) !=
+				((rep->ruledata->flags & AUDIT_FILTER_MASK) !=
 						AUDIT_FILTER_EXCLUDE)) {
 				printf(" syscall=");
 				for (sparse = 0, i = 0; 
 					i < (AUDIT_BITMASK_SIZE-1); i++) {
-					if (rep->rule->mask[i] != (uint32_t)~0)
+					if (rep->ruledata->mask[i] != (uint32_t)~0)
 						sparse = 1;
 				}
 				if (!sparse) {
@@ -1518,7 +1435,7 @@ static int audit_print_reply(struct audit_reply *rep)
 					i < AUDIT_BITMASK_SIZE * 32; i++) {
 					int word = AUDIT_WORD(i);
 					int bit  = AUDIT_BIT(i);
-					if (rep->rule->mask[word] & bit) {
+					if (rep->ruledata->mask[word] & bit) {
 						const char *ptr;
 						if (audit_elf)
 							machine = 
