@@ -1,5 +1,5 @@
 /* autrace.c -- 
- * Copyright 2005-08 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2005-09 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -49,7 +49,7 @@ static void usage(void)
 static int insert_rule(int audit_fd, const char *field)
 {
 	int rc;
-	int flags = AUDIT_FILTER_ENTRY;
+	int flags = AUDIT_FILTER_EXIT;
 	int action = AUDIT_ALWAYS;
 	struct audit_rule_data *rule = malloc(sizeof(struct audit_rule_data));
 
@@ -100,9 +100,11 @@ static int insert_rule(int audit_fd, const char *field)
 	rc = audit_add_rule_data(audit_fd, rule, flags, action);
 	if (rc < 0)
 		goto err;
+	free(rule);
 	return 0;
 err:
 	fprintf(stderr, "Error inserting audit rule for %s\n", field);
+	free(rule);
 	return 1;
 }
 
@@ -237,7 +239,7 @@ static int count_rules(void)
 	if (fd < 0) 
 		return -1;
 
-	rc = audit_request_rules_list(fd);
+	rc = audit_request_rules_list_data(fd);
 	if (rc > 0) 
 		total = count_em(fd);
 	else 
@@ -274,7 +276,7 @@ static int count_em(int fd)
 			{
 				case NLMSG_DONE:
 					return count;
-				case AUDIT_LIST:
+				case AUDIT_LIST_RULES:
 					i = 0;
 					count++;
 					break;
