@@ -69,6 +69,12 @@ int main(int argc, char *argv[])
 			fputs("Alpha processor support is not enabled\n",
 					stderr);
 			exit(1);
+#endif
+#ifndef WITH_ARMEB
+		} else if (strcmp("armeb", argv[i]) == 0) {
+			fputs("Arm eabi processor support is not enabled\n",
+					stderr);
+			exit(1);
 #endif
 		} else {
 			if (name != NULL) {
